BaseRegion class sealed

A geographical region that forms a particular shape

It can be converted to a:

Implementers
Annotations

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

maybeWhen<T>({T rectangle(RectangleRegion rectangle)?, T circle(CircleRegion circle)?, T line(LineRegion line)?, T customPolygon(CustomPolygonRegion customPolygon)?, T multi(MultiRegion multi)?}) → T?
Output a value of type T the type of this region
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDownloadable({required int minZoom, required int maxZoom, required TileLayer options, int start = 1, int? end, Crs crs = const Epsg3857()}) DownloadableRegion<BaseRegion>
Generate the DownloadableRegion ready for bulk downloading
toOutline() Iterable<LatLng>
Generate the list of all the LatLngs forming the outline of this region
toString() String
A string representation of this object.
inherited
when<T>({required T rectangle(RectangleRegion rectangle), required T circle(CircleRegion circle), required T line(LineRegion line), required T customPolygon(CustomPolygonRegion customPolygon), required T multi(MultiRegion multi)}) → T
Output a value of type T the type of this region

Operators

operator ==(Object other) bool
The equality operator.
override