BrowseLoadingStrategy enum

Determines whether the network or cache is preferred during browse caching, and how to fallback

BrowseLoadingStrategy Preferred method Fallback method
cacheOnly Cache None
cacheFirst Cache Network
onlineFirst Network Cache
Standard Tile Provider Network None
Inheritance
Available extensions

Values

cacheOnly → const BrowseLoadingStrategy

Only fetch tiles from the local cache

In this mode, BrowseStoreStrategy is irrelevant.

Throws FMTCBrowsingErrorType.missingInCacheOnlyMode if a tile is unavailable.

See documentation on BrowseLoadingStrategy for a strategy comparison table.

cacheFirst → const BrowseLoadingStrategy

Fetch tiles from the cache, falling back to the network to fetch and create/update non-existent/expired tiles, dependent on the selected BrowseStoreStrategy

See documentation on BrowseLoadingStrategy for a strategy comparison table.

onlineFirst → const BrowseLoadingStrategy

Fetch and create/update non-existent/expired tiles from the network, falling back to the cache to fetch tiles, dependent on the selected BrowseStoreStrategy

See documentation on BrowseLoadingStrategy for a strategy comparison table.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BrowseLoadingStrategy>
A constant List of the values in this enum, in order of their declaration.