CustomPolygonRegion class
A geographical region who's outline is defined by a list of coordinates
- Inheritance
-
- Object
- BaseRegion
- CustomPolygonRegion
Constructors
-
CustomPolygonRegion(List<
LatLng> outline) -
Create a geographical region who's outline is defined by a list of
coordinates
const
Properties
Methods
-
maybeWhen<
T> ({T rectangle(RectangleRegion rectangle)?, T circle(CircleRegion circle)?, T line(LineRegion line)?, T customPolygon(CustomPolygonRegion customPolygon)?, T multi(MultiRegion multi)?}) → T? -
Output a value of type
Tthe type of this regioninherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDownloadable(
{required int minZoom, required int maxZoom, required TileLayer options, int start = 1, int? end, Crs crs = const Epsg3857()}) → DownloadableRegion< CustomPolygonRegion> -
Generate the DownloadableRegion ready for bulk downloading
override
-
toOutline(
) → List< LatLng> -
Generate the list of all the
LatLngs forming the outline of this regionoverride -
toString(
) → String -
A string representation of this object.
inherited
-
when<
T> ({required T rectangle(RectangleRegion rectangle), required T circle(CircleRegion circle), required T line(LineRegion line), required T customPolygon(CustomPolygonRegion customPolygon), required T multi(MultiRegion multi)}) → T -
Output a value of type
Tthe type of this regioninherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override