DownloadProgress class

Statistics and information about the current progress of the download

See the documentation on each individual property for more information.

Annotations

Properties

attemptedTilesCount int
The number of tiles that have been attempted to download
no setter
bufferedTilesCount int
The number of tiles successfully downloaded but still to be written to the cache
final
bufferedTilesSize double
The size in KiB of the tile images successfully downloaded but still to be written to the cache
final
elapsedDuration Duration
The current elapsed duration of the download
final
estRemainingDuration Duration
The estimated remaining duration of the download
no setter
estTotalDuration Duration
The estimated total duration of the download
no setter
existingTilesCount int
The number of tiles skipped because they already existed in the cache and skipExistingTiles was enabled
final
existingTilesSize double
The size in KiB of the tile images skipped because they already existed in the cache and skipExistingTiles was enabled
final
failedRequestTilesCount int
The number of tiles that could not be downloaded because the HTTP request could not be made
final
failedTilesCount int
The number of tiles that could not be downloaded and are not in the queue to be retried (retryTilesQueuedCount)
no setter
flushedTilesCount int
The number of tiles successfully downloaded and written to the cache (flushed from the buffer)
no setter
flushedTilesSize double
The size in KiB of the tile images successfully downloaded and written to the cache (flushed from the buffer)
no setter
hashCode int
The hash code for this object.
no setteroverride
isTPSArtificiallyCapped bool
Whether the number of tilesPerSecond could be higher, but is currently capped by the set rateLimit
no setter
maxTilesCount int
The total number of tiles available to be potentially downloaded and cached
final
negativeResponseTilesCount int
The number of tiles that could not be downloaded because the HTTP response was not 200 OK
final
percentageProgress double
The percentage attemptedTilesCount is of maxTilesCount (expressed from 0 - 100)
no setter
remainingTilesCount int
The number of tiles remaining to be attempted to download
no setter
retryTilesQueuedCount int
The number of tiles that were queued to be retried
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seaTilesCount int
The number of tiles skipped because they were sea tiles and skipSeaTiles was enabled
final
seaTilesSize double
The size in KiB of the tile images skipped because they were sea tiles and skipSeaTiles was enabled
final
skippedTilesCount int
The number of tiles skipped (including both sea tiles and existing tiles, where their respective options are enabled when starting the download)
no setter
skippedTilesSize double
The size in KiB of the tile images skipped (including both sea tiles and existing tiles, where their respective options are enabled when starting the download)
no setter
successfulTilesCount int
The number of tiles successfully downloaded (including both tiles buffered and actually flushed/written to cache)
final
successfulTilesSize double
The size in KiB of the tile images successfully downloaded (including both tiles buffered and actually flushed/written to cache)
final
tilesPerSecond double
The approximate/estimated number of attempted tiles per second (TPS)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override