skippedTilesCount property

int get skippedTilesCount

The number of tiles skipped (including both sea tiles and existing tiles, where their respective options are enabled when starting the download)

This is the number of SkippedTileEvents emitted.

Implementation

int get skippedTilesCount => seaTilesCount + existingTilesCount;