DownloadableRegion<R extends BaseRegion> class
A downloadable region to be passed to bulk download functions
Construct via BaseRegion.toDownloadable.
- Annotations
Properties
- crs → Crs
-
The map projection to use to calculate tiles. Defaults to
Epsg3857.final - end → int?
-
Optionally skip any tiles after this tile
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- maxZoom → int
-
The maximum zoom level to fetch tiles for
final
- minZoom → int
-
The minimum zoom level to fetch tiles for
final
- options → TileLayer
-
The options used to fetch tiles
final
- originalRegion → R
-
A copy of the BaseRegion used to form this object
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- start → int
-
Optionally skip any tiles before this tile
final
Methods
-
cast<
N extends BaseRegion> () → DownloadableRegion< N> -
Cast originalRegion from
RtoN -
maybeWhen<
T> ({T rectangle(DownloadableRegion< RectangleRegion> rectangle)?, T circle(DownloadableRegion<CircleRegion> circle)?, T line(DownloadableRegion<LineRegion> line)?, T customPolygon(DownloadableRegion<CustomPolygonRegion> customPolygon)?, T multi(DownloadableRegion<MultiRegion> multi)?}) → T? -
Output a value of type
Tdependent on originalRegion and its typeR -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
T> ({required T rectangle(DownloadableRegion< RectangleRegion> rectangle), required T circle(DownloadableRegion<CircleRegion> circle), required T line(DownloadableRegion<LineRegion> line), required T customPolygon(DownloadableRegion<CustomPolygonRegion> customPolygon), required T multi(DownloadableRegion<MultiRegion> multi)}) → T -
Output a value of type
Tdependent on originalRegion and its typeR
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override