FMTCStore constructor

const FMTCStore(
  1. String storeName
)

Provides access to management, statistics, metadata, bulk download, the tile provider (and the export functionality) on the store named storeName

Important

Constructing an instance of this class will not automatically create it. To create this store, use manage > StoreManagement.create.

Implementation

const FMTCStore(this.storeName);