FailedRequestTileEvent class

The raw result of a failed request tile download during bulk downloading

Failed request means the request to the url was not made successfully (likely due to a network issue).

This tile will be added to the retry queue if retryFailedRequestTiles is enabled, and it was not already a retry attempt (wasRetryAttempt).

Inheritance
Annotations

Properties

coordinates → (int, int, int)
The (x, y, z) coordinates of this tile
finalinherited
fetchError Object
The raw error thrown when attempting to make a HTTP request to url
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
The URL used to request the tile
finalinherited
wasRetryAttempt bool
Whether this tile was a retry attempt of a FailedRequestTileEvent
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited