FailedTileEvent class sealed

The raw result of a failed tile download during bulk downloading

Failed means a request to url was attempted, but a HTTP 200 OK response was not recieved. See subclasses for specific failure reasons.

Inheritance
Implementers
Annotations

Properties

coordinates → (int, int, int)
The (x, y, z) coordinates of this tile
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
The URL used to request the tile
finalinherited
wasRetryAttempt bool
Whether this tile was a retry attempt of a FailedRequestTileEvent
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited