listStores property

Future<List<String>> get listStores

List the available store names within the archive at pathToArchive

pathToArchive must exist as an compatible file. The path must be accessible to the application: see pathToArchive for information. If it does not exist, ImportPathNotExists will be thrown. If it exists, but is not a file, ImportExportPathNotFile will be thrown. If it exists, but is not an FMTC archive, ImportFileNotFMTCStandard will be thrown. If it is an FMTC archive, but not compatible with the current backend, ImportFileNotBackendCompatible will be thrown.

Implementation

Future<List<String>> get listStores =>
    FMTCBackendAccess.internal.listImportableStores(path: pathToArchive);