delete method

Future<void> delete()

Delete the specified store

Warning

This operation cannot be undone! Ensure you confirm with the user that this action is expected.

Does nothing if the store does not already exist.

Implementation

Future<void> delete() =>
    FMTCBackendAccess.internal.deleteStore(storeName: _storeName);