removeTilesOlderThan method

Future<void> removeTilesOlderThan({
  1. required DateTime expiry,
})

Remove tiles that were last modified prior to the expiry timestamp from the specified store

For example, to remove tiles last modified over 14 days ago, calculate expiry with:

expiry: DateTime.timestamp().subtract(const Duration(days: 14))

Returns the number of tiles that were actually deleted (they were orphaned). See deleteTile for more information about orphan tiles.

Implementation

Future<void> removeTilesOlderThan({required DateTime expiry}) =>
    FMTCBackendAccess.internal
        .removeTilesOlderThan(storeName: _storeName, expiry: expiry);