rename method

Future<FMTCStore> rename(
  1. String newStoreName
)

Change the name of the specified store to the specified new store name

Important

The old FMTCStore will still retain it's link to the old store, so always use the new returned value instead: returns a new FMTCStore after a successful renaming operation.

Implementation

Future<FMTCStore> rename(String newStoreName) async {
  await FMTCBackendAccess.internal.renameStore(
    currentStoreName: _storeName,
    newStoreName: newStoreName,
  );

  return FMTCStore(newStoreName);
}