reset method

Future<void> reset()

Remove all the tiles from within the specified store

Also resets the hits & misses stats. Does not reset any associated metadata.

Warning

This operation cannot be undone! Ensure you confirm with the user that this action is expected.

Does nothing if the store does not already exist.

Implementation

Future<void> reset() =>
    FMTCBackendAccess.internal.resetStore(storeName: _storeName);