StoreNotExists class final
Indicates that the specified store structure was not available for use in operations, likely because it didn't exist
- Inheritance
-
- Object
- Error
- FMTCBackendError
- StoreNotExists
Constructors
- StoreNotExists({required String storeName})
- Indicates that the specified store structure was not available for use in operations, likely because it didn't exist
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace → StackTrace?
-
The stack trace at the point where this error was first thrown.
no setterinherited
- storeName → String
-
The referenced store name
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited