wasRetryAttempt property

bool wasRetryAttempt
final

Whether this tile was a retry attempt of a FailedRequestTileEvent

Never set if retryFailedRequestTiles is disabled.

Implies that the tile has been emitted before. Care should be taken to ensure that this does not cause issues (for example, duplication issues).

(This is also used internally to maintain DownloadProgress statistics.)

Implementation

final bool wasRetryAttempt;