BrowseStoreStrategy enum
Determines when tiles should be written to a store during browse caching
Values
- read → const BrowseStoreStrategy
-
Only read tiles
- readUpdate → const BrowseStoreStrategy
-
Read tiles, and also update existing tiles
Unlike 'create', if (an older version of) a tile does not already exist in the store, it will not be written.
- readUpdateCreate → const BrowseStoreStrategy
-
Read, update, and create tiles
See readUpdate for a definition of 'update'.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
BrowseStoreStrategy> - A constant List of the values in this enum, in order of their declaration.