CircleRegion class
A geographically circular region based off a center coord and radius
Constructors
-
CircleRegion(LatLng center, double radius)
-
Create a geographically circular region based off a
center coord and
radius
const
Properties
-
center
→ LatLng
-
Center coordinate
final
-
hashCode
→ int
-
The hash code for this object.
no setteroverride
-
radius
→ double
-
Radius in kilometers
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
maybeWhen<T>({T rectangle(RectangleRegion rectangle)?, T circle(CircleRegion circle)?, T line(LineRegion line)?, T customPolygon(CustomPolygonRegion customPolygon)?, T multi(MultiRegion multi)?})
→ T?
-
Output a value of type
T the type of this region
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toDownloadable({required int minZoom, required int maxZoom, required TileLayer options, int start = 1, int? end, Crs crs = const Epsg3857()})
→ DownloadableRegion<CircleRegion>
-
Generate the DownloadableRegion ready for bulk downloading
override
-
toOutline()
→ Iterable<LatLng>
-
Generate the list of all the
LatLngs forming the outline of this region
override
-
toString()
→ String
-
A string representation of this object.
inherited
-
when<T>({required T rectangle(RectangleRegion rectangle), required T circle(CircleRegion circle), required T line(LineRegion line), required T customPolygon(CustomPolygonRegion customPolygon), required T multi(MultiRegion multi)})
→ T
-
Output a value of type
T the type of this region
inherited