failedTilesCount property
int
get
failedTilesCount
The number of tiles that could not be downloaded and are not in the queue to be retried (retryTilesQueuedCount)
See failedRequestTilesCount for more information about how that metric is affected by retry tiles.
Implementation
int get failedTilesCount =>
negativeResponseTilesCount + failedRequestTilesCount;