NegativeResponseTileEvent class
The raw result of a negative response tile download during bulk downloading
Negative response means the request to the url was made successfully, but a HTTP 200 OK response was not received.
- Inheritance
-
- Object
- TileEvent
- FailedTileEvent
- NegativeResponseTileEvent
- Mixed-in types
- Annotations
Properties
- coordinates → (int, int, int)
-
The (x, y, z) coordinates of this tile
finalinherited
- fetchResponse → Response
-
The raw HTTP response from the GET request to url
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- url → String
-
The URL used to request the tile
finalinherited
- wasRetryAttempt → bool
-
Whether this tile was a retry attempt of a FailedRequestTileEvent
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited