watchRecovery method
- @Deprecated('Use `FMTCRoot.recovery.watch()` instead. ' 'This is more suited to the context of the recovery methods. ' 'This feature was deprecated in v10, and will be removed in a future ' 'version.')
- bool triggerImmediately = false,
Watch for changes to the recovery system
Useful to update UI only when required, for example, in a StreamBuilder.
Whenever this has an event, it is likely the other statistics will have
changed.
Implementation
@Deprecated(
'Use `FMTCRoot.recovery.watch()` instead. '
'This is more suited to the context of the recovery methods. '
'This feature was deprecated in v10, and will be removed in a future '
'version.',
)
Stream<void> watchRecovery({
bool triggerImmediately = false,
}) =>
FMTCRoot.recovery.watch(triggerImmediately: triggerImmediately);