check method
- @Deprecated('Use `countTiles()` instead. ' 'The new name is less ambiguous and aligns better with recommended Dart ' 'code style. ' 'This feature was deprecated in v10, and will be removed in a future ' 'version.')
- DownloadableRegion<
BaseRegion> region
Count the number of tiles within the specified region
This does not include skipped sea tiles or skipped existing tiles, as those are handled during a download (as the contents must be known).
Note that this does not require an existing/ready store, or a sensical DownloadableRegion.options.
Implementation
@Deprecated(
'Use `countTiles()` instead. '
'The new name is less ambiguous and aligns better with recommended Dart '
'code style. '
'This feature was deprecated in v10, and will be removed in a future '
'version.',
)
Future<int> check(DownloadableRegion region) => countTiles(region);