create method
Create a new store with the specified name
If set, maxLength will be the maximum allowed number of tiles in the
store. This limit is enforced automatically when browse caching, but not
when bulk downloading. Defaults to null: unlimited.
Does nothing if the store already exists.
Implementation
Future<void> create({int? maxLength}) =>
FMTCBackendAccess.internal.createStore(
storeName: _storeName,
maxLength: maxLength,
);