maxLength property
Retrieve the maximum allowable number of tiles within the specified store
This limit is enforced automatically when browse caching, but not when bulk downloading.
null means there is no configured limit.
Implementation
Future<int?> get maxLength =>
FMTCBackendAccess.internal.storeGetMaxLength(storeName: _storeName);