setMaxLength method
Set the maximum allowable number of tiles within the specified store
This limit is enforced automatically when browse caching, but not when bulk downloading.
Set null to disable the limit.
Implementation
Future<void> setMaxLength(int? newMaxLength) =>
FMTCBackendAccess.internal.storeSetMaxLength(
storeName: _storeName,
newMaxLength: newMaxLength,
);