TileEvent class sealed
The result of a tile download during bulk downloading
Does not contain information about the download as a whole, that is DownloadProgress' scope.
See specific subclasses for more information about the event. This is a sealed tree, so there are a guaranteed knowable set of results.
- Implementers
- Annotations
Properties
- coordinates → (int, int, int)
-
The (x, y, z) coordinates of this tile
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- url → String
-
The URL used to request the tile
final
- wasRetryAttempt → bool
-
Whether this tile was a retry attempt of a FailedRequestTileEvent
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override